==> brmo-stufbg204-1.5.0-sources.jar: nl/egem/stuf/sector/bg/_0204/BSGKerngegevens.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * Bestemmingsgebied kerngegevens
 * 
 * <p>Java class for BSG-kerngegevens complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BSG-kerngegevens">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="naamBestemmingsplan">
 *           &lt;complexType>
 *             &lt;simpleContent>
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>NaamBestemmingsplan">
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *               &lt;/extension>
 *             &lt;/simpleContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="omschrijvingBestemmingsgebied">
 *           &lt;complexType>
 *             &lt;simpleContent>
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>OmschrijvingBestemmingsgebied">
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *               &lt;/extension>
 *             &lt;/simpleContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}fundamenteel"/>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BSG-kerngegevens", propOrder = {
    "naamBestemmingsplan",
    "omschrijvingBestemmingsgebied"
})
public class BSGKerngegevens {

    @XmlElement(required = true, nillable = true)
    protected BSGKerngegevens.NaamBestemmingsplan naamBestemmingsplan;
    @XmlElement(required = true, nillable = true)
    protected BSGKerngegevens.OmschrijvingBestemmingsgebied omschrijvingBestemmingsgebied;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "sleutelVerzendend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelVerzendend;
    @XmlAttribute(name = "sleutelOntvangend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelOntvangend;
    @XmlAttribute(name = "sleutelGegevensbeheer", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelGegevensbeheer;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the naamBestemmingsplan property.
     * 
     * @return
     *     possible object is
     *     {@link BSGKerngegevens.NaamBestemmingsplan }
     *     
     */
    public BSGKerngegevens.NaamBestemmingsplan getNaamBestemmingsplan() {
        return naamBestemmingsplan;
    }

    /**
     * Sets the value of the naamBestemmingsplan property.
     * 
     * @param value
     *     allowed object is
     *     {@link BSGKerngegevens.NaamBestemmingsplan }
     *     
     */
    public void setNaamBestemmingsplan(BSGKerngegevens.NaamBestemmingsplan value) {
        this.naamBestemmingsplan = value;
    }

    /**
     * Gets the value of the omschrijvingBestemmingsgebied property.
     * 
     * @return
     *     possible object is
     *     {@link BSGKerngegevens.OmschrijvingBestemmingsgebied }
     *     
     */
    public BSGKerngegevens.OmschrijvingBestemmingsgebied getOmschrijvingBestemmingsgebied() {
        return omschrijvingBestemmingsgebied;
    }

    /**
     * Sets the value of the omschrijvingBestemmingsgebied property.
     * 
     * @param value
     *     allowed object is
     *     {@link BSGKerngegevens.OmschrijvingBestemmingsgebied }
     *     
     */
    public void setOmschrijvingBestemmingsgebied(BSGKerngegevens.OmschrijvingBestemmingsgebied value) {
        this.omschrijvingBestemmingsgebied = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "F";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the sleutelVerzendend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelVerzendend() {
        return sleutelVerzendend;
    }

    /**
     * Sets the value of the sleutelVerzendend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelVerzendend(String value) {
        this.sleutelVerzendend = value;
    }

    /**
     * Gets the value of the sleutelOntvangend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelOntvangend() {
        return sleutelOntvangend;
    }

    /**
     * Sets the value of the sleutelOntvangend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelOntvangend(String value) {
        this.sleutelOntvangend = value;
    }

    /**
     * Gets the value of the sleutelGegevensbeheer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelGegevensbeheer() {
        return sleutelGegevensbeheer;
    }

    /**
     * Sets the value of the sleutelGegevensbeheer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelGegevensbeheer(String value) {
        this.sleutelGegevensbeheer = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;simpleContent>
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>NaamBestemmingsplan">
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
     *     &lt;/extension>
     *   &lt;/simpleContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class NaamBestemmingsplan {

        @XmlValue
        protected String value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setValue(String value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;simpleContent>
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>OmschrijvingBestemmingsgebied">
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
     *     &lt;/extension>
     *   &lt;/simpleContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class OmschrijvingBestemmingsgebied {

        @XmlValue
        protected String value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setValue(String value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/sector/bg/_0204/BSGKerngegevens.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * Bestemmingsgebied kerngegevens
 * 
 * <p>Java class for BSG-kerngegevens complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BSG-kerngegevens"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="naamBestemmingsplan"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;NaamBestemmingsplan"&gt;
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="omschrijvingBestemmingsgebied"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;OmschrijvingBestemmingsgebied"&gt;
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}fundamenteel"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BSG-kerngegevens", propOrder = {
    "naamBestemmingsplan",
    "omschrijvingBestemmingsgebied"
})
public class BSGKerngegevens {

    @XmlElement(required = true, nillable = true)
    protected BSGKerngegevens.NaamBestemmingsplan naamBestemmingsplan;
    @XmlElement(required = true, nillable = true)
    protected BSGKerngegevens.OmschrijvingBestemmingsgebied omschrijvingBestemmingsgebied;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "sleutelVerzendend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelVerzendend;
    @XmlAttribute(name = "sleutelOntvangend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelOntvangend;
    @XmlAttribute(name = "sleutelGegevensbeheer", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelGegevensbeheer;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the naamBestemmingsplan property.
     * 
     * @return
     *     possible object is
     *     {@link BSGKerngegevens.NaamBestemmingsplan }
     *     
     */
    public BSGKerngegevens.NaamBestemmingsplan getNaamBestemmingsplan() {
        return naamBestemmingsplan;
    }

    /**
     * Sets the value of the naamBestemmingsplan property.
     * 
     * @param value
     *     allowed object is
     *     {@link BSGKerngegevens.NaamBestemmingsplan }
     *     
     */
    public void setNaamBestemmingsplan(BSGKerngegevens.NaamBestemmingsplan value) {
        this.naamBestemmingsplan = value;
    }

    /**
     * Gets the value of the omschrijvingBestemmingsgebied property.
     * 
     * @return
     *     possible object is
     *     {@link BSGKerngegevens.OmschrijvingBestemmingsgebied }
     *     
     */
    public BSGKerngegevens.OmschrijvingBestemmingsgebied getOmschrijvingBestemmingsgebied() {
        return omschrijvingBestemmingsgebied;
    }

    /**
     * Sets the value of the omschrijvingBestemmingsgebied property.
     * 
     * @param value
     *     allowed object is
     *     {@link BSGKerngegevens.OmschrijvingBestemmingsgebied }
     *     
     */
    public void setOmschrijvingBestemmingsgebied(BSGKerngegevens.OmschrijvingBestemmingsgebied value) {
        this.omschrijvingBestemmingsgebied = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "F";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the sleutelVerzendend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelVerzendend() {
        return sleutelVerzendend;
    }

    /**
     * Sets the value of the sleutelVerzendend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelVerzendend(String value) {
        this.sleutelVerzendend = value;
    }

    /**
     * Gets the value of the sleutelOntvangend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelOntvangend() {
        return sleutelOntvangend;
    }

    /**
     * Sets the value of the sleutelOntvangend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelOntvangend(String value) {
        this.sleutelOntvangend = value;
    }

    /**
     * Gets the value of the sleutelGegevensbeheer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelGegevensbeheer() {
        return sleutelGegevensbeheer;
    }

    /**
     * Sets the value of the sleutelGegevensbeheer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelGegevensbeheer(String value) {
        this.sleutelGegevensbeheer = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;NaamBestemmingsplan"&gt;
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class NaamBestemmingsplan {

        @XmlValue
        protected String value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setValue(String value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;OmschrijvingBestemmingsgebied"&gt;
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class OmschrijvingBestemmingsgebied {

        @XmlValue
        protected String value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setValue(String value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }

}
